# libpythonpro
Módulo para exemplificar a construção de projetos Python no curso PyTools

Nesse curso é ensidado como contribuir comprojetos de código aberto.

Link do curso [Python Pro](https://pythonpro.com.br/)

[![Build Status](https://travis-ci.com/eduardobazler/libpythonpro.svg?branch=main)](https://travis-ci.com/eduardobazler/libpythonpro)

Suportada aversão de Python3

Para instalar: 

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements
```
Para conferir qualidade do código:

```console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
 